@@ -1,7 +1,7 @@
 package App::CreateSparseFile;
 
-our $DATE = '2014-12-11'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -135,7 +135,7 @@ App::CreateSparseFile - Create sparse file
 
 =head1 VERSION
 
-This document describes version 0.04 of App::CreateSparseFile (from Perl distribution App-CreateSparseFile), released on 2014-12-11.
+This document describes version 0.05 of App::CreateSparseFile (from Perl distribution App-CreateSparseFile), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -146,7 +146,7 @@ See L<create-sparse-file>.
 
 =head2 create_sparse_file(%args) -> [status, msg, result, meta]
 
-Create sparse file.
+{en_US Create sparse file}.
 
 Examples:
 
@@ -156,12 +156,14 @@ Examples:
 Create a sparse file called file.bin with size of 30GB.
 
 
+{en_US 
 Sparse file is a file with a predefined size (sometimes large) but does not yet
 allocate all its (blank) data on disk. Sparse file is a feature of filesystem.
 
 I usually create sparse file when I want to create a large disk image but do not
 want to preallocate its data yet. Creating a sparse file should be virtually
 instantaneous.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -169,28 +171,30 @@ Arguments ('*' denotes required arguments):
 
 =item * B<interactive> => I<bool> (default: 1)
 
-Whether or not the program should be interactive.
+{en_US Whether or not the program should be interactive}.
 
+{en_US 
 If set to false then will not prompt interactively and usually will proceed
 (unless for dangerous stuffs, in which case will bail immediately.
+}
 
 =item * B<name>* => I<str>
 
 =item * B<override> => I<bool> (default: 0)
 
-Whether to override existing file.
+{en_US Whether to override existing file}.
 
+{en_US 
 If se to true then will override existing file without warning. The default is
 to prompt, or bail (if not interactive).
+}
 
 =item * B<size>* => I<str>
 
-Size (e.g. 10K, 22.5M).
+{en_US Size (e.g. 10K, 22.5M)}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -200,7 +204,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -224,7 +228,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
